@@ -10,7 +10,8 @@
 ******************************************************************************/
 
 #include "precompiled_header.hpp"
-#include <tango.h>
+#include <tango/tango.h>
+#include "pyutils.h"
 
 using namespace boost::python;
 
