@@ -90,27 +90,18 @@ namespace PyAttribute
      * Tango Attribute set_value wrapper for DevEncoded attributes
      *
      * @param att attribute reference
-     * @param data_str new attribute data string
-     * @param data new attribute data
+     * @param encoding_str new attribute encoding info
+     * @param data_str new attribute data
      */
     inline void __set_value(Tango::Attribute &att,
-                            bopy::str &data_str,
-                            bopy::str &data)
+                            bopy::str &encoding_str,
+                            bopy::str &data_str)
     {
-        extract<Tango::DevString> val_str(data_str.ptr());
-        if (!val_str.check())
-        {
-            throw_wrong_python_data_type(att.get_name(), "set_value()");
-        }
-        extract<Tango::DevString> val(data.ptr());
-        if (!val.check())
-        {
-            throw_wrong_python_data_type(att.get_name(), "set_value()");
-        }
+        Tango::DevString encoding_char = from_str_to_char(encoding_str);
+        Py_ssize_t size;
+        Tango::DevString data_char = from_str_to_char(data_str, &size, true);
 
-        Tango::DevString val_str_real = val_str;
-        Tango::DevString val_real = val;
-        att.set_value(&val_str_real, (Tango::DevUChar*)val_real, (long)len(data));
+        att.set_value(&encoding_char, (Tango::DevUChar*)data_char, (long)size, true);
     }
 
     /**
@@ -121,26 +112,14 @@ namespace PyAttribute
      * @param data new attribute data
      */
     inline void __set_value(Tango::Attribute &att,
-                            bopy::str &data_str,
-                            bopy::object &data)
+                            bopy::str &encoding_str,
+                            bopy::object &data_obj)
     {
-        extract<Tango::DevString> val_str(data_str.ptr());
-        if (!val_str.check())
-        {
-            throw_wrong_python_data_type(att.get_name(), "set_value()");
-        }
+        Tango::DevString encoding_char = from_str_to_char(encoding_str);
+        Py_ssize_t size;
+        Tango::DevString data_char = from_str_to_char(data_obj, &size, true);
 
-        PyObject* data_ptr = data.ptr();
-        Py_buffer view;
-
-        if (PyObject_GetBuffer(data_ptr, &view, PyBUF_FULL_RO) < 0)
-        {
-            throw_wrong_python_data_type(att.get_name(), "set_value()");
-        }
-
-        Tango::DevString val_str_real = val_str;
-            att.set_value(&val_str_real, (Tango::DevUChar*)view.buf, (long)view.len);
-        PyBuffer_Release(&view);
+        att.set_value(&encoding_char, (Tango::DevUChar*)data_char, (long)size, true);
     }
 
     /**
@@ -178,68 +157,49 @@ namespace PyAttribute
      * Tango Attribute set_value_date_quality wrapper for DevEncoded attributes
      *
      * @param att attribute reference
-     * @param data_str new attribute data string
-     * @param data new attribute data
+     * @param encoding_str new attribute data string
+     * @param data_str new attribute data
      * @param t timestamp
      * @param quality attribute quality
      */
     inline void __set_value_date_quality(Tango::Attribute &att,
+                                         bopy::str &encoding_str,
                                          bopy::str &data_str,
-                                         bopy::str &data,
                                          double t, Tango::AttrQuality quality)
     {
-        extract<Tango::DevString> val_str(data_str.ptr());
-        if (!val_str.check())
-        {
-            throw_wrong_python_data_type(att.get_name(), "set_value1()");
-        }
-        extract<Tango::DevString> val(data.ptr());
-        if (!val.check())
-        {
-            throw_wrong_python_data_type(att.get_name(), "set_value2()");
-        }
+        Tango::DevString encoding_char = from_str_to_char(encoding_str);
+        Py_ssize_t size;
+        Tango::DevString data_char = from_str_to_char(data_str, &size, true);
 
         PYTG_NEW_TIME_FROM_DOUBLE(t, tv);
-        Tango::DevString val_str_real = val_str;
-        Tango::DevString val_real = val;
-        att.set_value_date_quality(&val_str_real, (Tango::DevUChar*)val_real,
-                                   (long)len(data), tv, quality);
+
+        att.set_value_date_quality(&encoding_char, (Tango::DevUChar*)data_char,
+                                   (long)size, tv, quality, true);
     }
 
     /**
      * Tango Attribute set_value_date_quality wrapper for DevEncoded attributes
      *
      * @param att attribute reference
-     * @param data_str new attribute data string
-     * @param data new attribute data
+     * @param encoding_str new attribute data string
+     * @param data_obj new attribute data
      * @param t timestamp
      * @param quality attribute quality
      */
     inline void __set_value_date_quality(Tango::Attribute &att,
-                                         bopy::str &data_str,
-                                         bopy::object &data,
+                                         bopy::str &encoding_str,
+                                         bopy::object &data_obj,
                                          double t, Tango::AttrQuality quality)
     {
-        extract<Tango::DevString> val_str(data_str.ptr());
-        if (!val_str.check())
-        {
-            throw_wrong_python_data_type(att.get_name(), "set_value1()");
-        }
-
-	PyObject* data_ptr = data.ptr();
-	Py_buffer view;
-	
-	if (PyObject_GetBuffer(data_ptr, &view, PyBUF_FULL_RO) < 0)
-	{
-	    throw_wrong_python_data_type(att.get_name(), "set_value()");
-	}
+        Tango::DevString encoding_char = from_str_to_char(encoding_str);
+        Py_ssize_t size;
+        Tango::DevString data_char = from_str_to_char(data_obj, &size, true);
 
         PYTG_NEW_TIME_FROM_DOUBLE(t, tv);
-	Tango::DevString val_str_real = val_str;
-        att.set_value_date_quality(&val_str_real, (Tango::DevUChar*)view.buf,
-                                   (long)view.len, tv, quality);
-	PyBuffer_Release(&view);
-    }
+
+        att.set_value_date_quality(&encoding_char, (Tango::DevUChar*)data_char,
+                                   (long)size, tv, quality, true);
+        }
 
     template<long tangoTypeConst>
     void __set_value_date_quality_array(
