@@ -36,8 +36,8 @@ using namespace boost::python;
     try { boost::python::call_method<void>(m_self, #name, __VA_ARGS__); } \
     __AUX_CATCH_PY_EXCEPTION
 
-CppDeviceClass::CppDeviceClass(const string &name)
-    :Tango::DeviceClass(const_cast<string&>(name))
+CppDeviceClass::CppDeviceClass(const std::string &name)
+    :Tango::DeviceClass(const_cast<std::string&>(name))
 {}
 
 CppDeviceClass::~CppDeviceClass()
@@ -70,7 +70,16 @@ void CppDeviceClass::create_command(const std::string &cmd_name,
         command_list.push_back(cmd_ptr);
 }
 
-void CppDeviceClass::create_attribute(vector<Tango::Attr *> &att_list,
+void CppDeviceClass::create_fwd_attribute(std::vector<Tango::Attr *> &att_list,
+		const std::string &attr_name,
+		Tango::UserDefaultFwdAttrProp *att_prop)
+{
+	Tango::FwdAttr *attr_ptr = new Tango::FwdAttr(attr_name);
+	attr_ptr->set_default_properties(*att_prop);
+	att_list.push_back(attr_ptr);
+}
+
+void CppDeviceClass::create_attribute(std::vector<Tango::Attr *> &att_list,
 				      const std::string &attr_name,
 				      Tango::CmdArgType attr_type,
 				      Tango::AttrDataFormat attr_format,
@@ -120,7 +129,7 @@ void CppDeviceClass::create_attribute(vector<Tango::Attr *> &att_list,
             TangoSys_OMemStream o;
             o << "Attribute " << attr_name << " has an unexpected data format\n"
               << "Please report this bug to the PyTango development team"
-              << ends;
+              << std::ends;
             Tango::Except::throw_exception(
                     (const char *)"PyDs_UnexpectedAttributeFormat",
                     o.str(),
@@ -147,7 +156,7 @@ void CppDeviceClass::create_attribute(vector<Tango::Attr *> &att_list,
 
     att_list.push_back(attr_ptr);
 }
-void CppDeviceClass::create_pipe(vector<Tango::Pipe *> &pipe_list,
+void CppDeviceClass::create_pipe(std::vector<Tango::Pipe *> &pipe_list,
 				 const std::string &name,
 				 Tango::PipeWriteType access,
 				 Tango::DispLevel display_level,
@@ -294,35 +303,14 @@ void CppDeviceClassWrap::default_signal_handler(long signo)
     this->Tango::DeviceClass::signal_handler(signo);
 }
 
-void CppDeviceClassWrap::delete_class()
-{
-    AutoPythonGIL __py_lock;
-
-    try
-    {
-        //
-        // Call the delete_class_list function in order to clear the global
-        // constructed class Python list. It is MANDATORY to destroy these objects
-        // from Python. Otherwise, there are "seg fault" when Python exit.
-        // It tooks me quite a long time to find this...
-        //
-        PYTANGO_MOD
-        pytango.attr("delete_class_list")();
-    }
-    catch(error_already_set &eas)
-    {
-        handle_python_exception(eas);
-    }
-}
-
 namespace PyDeviceClass
 {
 
     object get_device_list(CppDeviceClass &self)
     {
         boost::python::list py_dev_list;
-        vector<Tango::DeviceImpl *> dev_list = self.get_device_list();
-        for(vector<Tango::DeviceImpl *>::iterator it = dev_list.begin(); it != dev_list.end(); ++it)
+        std::vector<Tango::DeviceImpl *> dev_list = self.get_device_list();
+        for(std::vector<Tango::DeviceImpl *>::iterator it = dev_list.begin(); it != dev_list.end(); ++it)
         {
             object py_value = object(
                         handle<>(
@@ -337,8 +325,8 @@ namespace PyDeviceClass
     object get_command_list(CppDeviceClass &self)
     {
         boost::python::list py_cmd_list;
-        vector<Tango::Command *> cmd_list = self.get_command_list();
-        for(vector<Tango::Command *>::iterator it = cmd_list.begin(); 
+        std::vector<Tango::Command *> cmd_list = self.get_command_list();
+        for(std::vector<Tango::Command *>::iterator it = cmd_list.begin(); 
 	    it != cmd_list.end(); ++it)
         {
             object py_value = object(
@@ -354,8 +342,9 @@ namespace PyDeviceClass
     object get_pipe_list(CppDeviceClass &self, const std::string& dev_name)
     {
         boost::python::list py_pipe_list;
-        vector<Tango::Pipe *> pipe_list = self.get_pipe_list(dev_name);
-        for(vector<Tango::Pipe *>::iterator it = pipe_list.begin();
+        std::vector<Tango::Pipe *> pipe_list = self.get_pipe_list(dev_name);
+//        std::vector<Tango::Pipe *> pipe_list = self.get_pipe_list();
+        for(std::vector<Tango::Pipe *>::iterator it = pipe_list.begin();
 	    it != pipe_list.end(); ++it)
         {
             object py_value = object(
@@ -389,16 +378,8 @@ BOOST_PYTHON_MEMBER_FUNCTION_OVERLOADS (export_device_overload,
 
 void export_device_class()
 {
-    void (Tango::DeviceClass::*add_wiz_dev_prop_)(string &,string &) =
-        &Tango::DeviceClass::add_wiz_dev_prop;
-    void (Tango::DeviceClass::*add_wiz_dev_prop__)(string &,string &,string &) =
-        &Tango::DeviceClass::add_wiz_dev_prop;
-    void (Tango::DeviceClass::*add_wiz_class_prop_)(string &,string &) =
-        &Tango::DeviceClass::add_wiz_class_prop;
-    void (Tango::DeviceClass::*add_wiz_class_prop__)(string &,string &,string &) =
-        &Tango::DeviceClass::add_wiz_class_prop;
 
-    class_<CppDeviceClass, auto_ptr<CppDeviceClassWrap>, boost::noncopyable>("DeviceClass",
+    class_<CppDeviceClass, std::auto_ptr<CppDeviceClassWrap>, boost::noncopyable>("DeviceClass",
         init<const std::string &>())
 
         .def("device_factory", &CppDeviceClassWrap::device_factory)
@@ -437,25 +418,26 @@ void export_device_class()
             &Tango::DeviceClass::set_type)
         .def("add_wiz_dev_prop",
             (void (Tango::DeviceClass::*) (const std::string &, const std::string &))
-            add_wiz_dev_prop_)
+            &Tango::DeviceClass::add_wiz_dev_prop)
         .def("add_wiz_dev_prop",
             (void (Tango::DeviceClass::*) (const std::string &, const std::string &, const std::string &))
-            add_wiz_dev_prop__)
+            &Tango::DeviceClass::add_wiz_dev_prop)
         .def("add_wiz_class_prop",
             (void (Tango::DeviceClass::*) (const std::string &, const std::string &))
-            add_wiz_class_prop_)
+            &Tango::DeviceClass::add_wiz_class_prop)
         .def("add_wiz_class_prop",
             (void (Tango::DeviceClass::*) (const std::string &, const std::string &, const std::string &))
-            add_wiz_class_prop__)
+            &Tango::DeviceClass::add_wiz_class_prop)
         .def("_device_destroyer",
             (void (Tango::DeviceClass::*) (const char *))
             &Tango::DeviceClass::device_destroyer)
         .def("_create_attribute", &CppDeviceClass::create_attribute)
+        .def("_create_fwd_attribute", &CppDeviceClass::create_fwd_attribute)
         .def("_create_pipe", &CppDeviceClass::create_pipe)
         .def("_create_command", &CppDeviceClass::create_command)
         .def("get_class_attr", &Tango::DeviceClass::get_class_attr,
             return_value_policy<reference_existing_object>())
     ;
-    implicitly_convertible<auto_ptr<CppDeviceClassWrap>, auto_ptr<CppDeviceClass> >();
+    implicitly_convertible<std::auto_ptr<CppDeviceClassWrap>, std::auto_ptr<CppDeviceClass> >();
 }
 
