@@ -113,8 +113,7 @@ static void log_to_stream(log4tango::LoggerStream& stream,
 // we don't use extract<> from boost bellow to get attribute name because it is
 // considerably slow
 #define SAFE_PUSH(dev, attr, attr_name) \
-    std::string __att_name; \
-    from_str_to_char(attr_name.ptr(), __att_name); \
+    std::string __att_name = from_str_to_char(attr_name.ptr()); \
     AutoPythonAllowThreads python_guard_ptr; \
     Tango::AutoTangoMonitor tango_guard(&dev); \
     Tango::Attribute & attr = dev.get_device_attr()->get_attr_by_name(__att_name.c_str()); \
@@ -536,8 +535,7 @@ namespace PyDeviceImpl
      * **********************************/
     inline void push_pipe_event(Tango::DeviceImpl &self, str &pipe_name, object& pipe_data)
     {
-    	std::string __pipe_name;
-    	from_str_to_char(pipe_name.ptr(), __pipe_name);
+        std::string __pipe_name = from_str_to_char(pipe_name.ptr());
     	boost::python::extract<Tango::DevFailed> except_convert(pipe_data);
     	if (except_convert.check()) {
     		self.push_pipe_event(__pipe_name, const_cast<Tango::DevFailed*>(&except_convert()));
@@ -1013,6 +1011,16 @@ void Device_3ImplWrap::init_device()
     }
 }
 
+void Device_3ImplWrap::server_init_hook()
+{
+    CALL_DEVICE_METHOD(Device_3Impl, server_init_hook)
+}
+
+void Device_3ImplWrap::default_server_init_hook()
+{
+    this->Tango::Device_3Impl::server_init_hook();
+}
+
 void Device_3ImplWrap::delete_device()
 {
     CALL_DEVICE_METHOD(Device_3Impl, delete_device)
@@ -1188,6 +1196,16 @@ void Device_4ImplWrap::init_device()
     }
 }
 
+void Device_4ImplWrap::server_init_hook()
+{
+    CALL_DEVICE_METHOD(Device_4Impl, server_init_hook)
+}
+
+void Device_4ImplWrap::default_server_init_hook()
+{
+    this->Tango::Device_4Impl::server_init_hook();
+}
+
 void Device_4ImplWrap::delete_device()
 {
     CALL_DEVICE_METHOD(Device_4Impl, delete_device)
@@ -1356,6 +1374,16 @@ void Device_5ImplWrap::init_device()
     }
 }
 
+void Device_5ImplWrap::server_init_hook()
+{
+    CALL_DEVICE_METHOD(Device_5Impl, server_init_hook)
+}
+
+void Device_5ImplWrap::default_server_init_hook()
+{
+    this->Tango::Device_5Impl::server_init_hook();
+}
+
 void Device_5ImplWrap::delete_device()
 {
     CALL_DEVICE_METHOD(Device_5Impl, delete_device)
@@ -1765,6 +1793,8 @@ void export_device_impl()
             init<CppDeviceClass *, const char *,
                  boost::python::optional<const char *, Tango::DevState, const char *> >())
         .def("init_device", pure_virtual(&Tango::Device_3Impl::init_device))
+        .def("server_init_hook", &Tango::Device_3Impl::server_init_hook,
+             &Device_3ImplWrap::default_server_init_hook)
         .def("delete_device", &Tango::Device_3Impl::delete_device,
             &Device_3ImplWrap::default_delete_device)
         .def("always_executed_hook", &Tango::Device_3Impl::always_executed_hook,
@@ -1790,6 +1820,8 @@ void export_device_impl()
             init<CppDeviceClass *, const char *,
                  boost::python::optional<const char *, Tango::DevState, const char *> >())
         .def("init_device", pure_virtual(&Tango::Device_4Impl::init_device))
+        .def("server_init_hook", &Tango::Device_4Impl::server_init_hook,
+             &Device_4ImplWrap::default_server_init_hook)
         .def("delete_device", &Tango::Device_4Impl::delete_device,
             &Device_4ImplWrap::default_delete_device)
         .def("always_executed_hook", &Tango::Device_4Impl::always_executed_hook,
@@ -1814,6 +1846,8 @@ void export_device_impl()
             init<CppDeviceClass *, const char *,
                  boost::python::optional<const char *, Tango::DevState, const char *> >())
         .def("init_device", pure_virtual(&Tango::Device_5Impl::init_device))
+        .def("server_init_hook", &Tango::Device_5Impl::server_init_hook,
+             &Device_5ImplWrap::default_server_init_hook)
         .def("delete_device", &Tango::Device_5Impl::delete_device,
             &Device_5ImplWrap::default_delete_device)
         .def("always_executed_hook", &Tango::Device_5Impl::always_executed_hook,
