@@ -14,11 +14,7 @@
 import os
 from functools import wraps
 
-# Compatibility imports
-try:
-    from threading import get_ident
-except Exception:
-    from threading import _get_ident as get_ident
+from threading import get_ident
 
 # Tango imports
 from ._tango import GreenMode
