@@ -17,20 +17,57 @@ __all__ = ("pytango_pprint_init",)
 
 __docformat__ = "restructuredtext"
 
-from ._tango import (StdStringVector, StdLongVector, CommandInfoList,
-                     AttributeInfoList, AttributeInfoListEx, PipeInfoList,
-                     DeviceDataHistoryList,
-                     GroupReplyList, GroupAttrReplyList, GroupCmdReplyList,
-                     DbData, DbDevInfos, DbDevExportInfos, DbDevImportInfos, DbHistoryList,
-                     LockerInfo, DevCommandInfo, AttributeDimension, CommandInfo, PipeInfo,
-                     DeviceInfo, DeviceAttributeConfig, AttributeInfo, AttributeAlarmInfo,
-                     ChangeEventInfo, PeriodicEventInfo, ArchiveEventInfo,
-                     AttributeEventInfo, AttributeInfoEx,
-                     DeviceAttribute, DeviceAttributeHistory, DeviceData, DeviceDataHistory,
-                     DevicePipe, DbDatum, DbDevInfo, DbDevImportInfo, DbDevExportInfo,
-                     DbServerInfo, GroupReply, GroupAttrReply, GroupCmdReply,
-                     DevError, EventData, AttrConfEventData, DataReadyEventData,
-                     TimeVal, DevFailed, CmdArgType)
+from ._tango import (
+    StdStringVector,
+    StdLongVector,
+    CommandInfoList,
+    AttributeInfoList,
+    AttributeInfoListEx,
+    PipeInfoList,
+    DeviceDataHistoryList,
+    GroupReplyList,
+    GroupAttrReplyList,
+    GroupCmdReplyList,
+    DbData,
+    DbDevInfos,
+    DbDevExportInfos,
+    DbDevImportInfos,
+    DbHistoryList,
+    LockerInfo,
+    DevCommandInfo,
+    AttributeDimension,
+    CommandInfo,
+    PipeInfo,
+    DeviceInfo,
+    DeviceAttributeConfig,
+    AttributeInfo,
+    AttributeAlarmInfo,
+    ChangeEventInfo,
+    PeriodicEventInfo,
+    ArchiveEventInfo,
+    AttributeEventInfo,
+    AttributeInfoEx,
+    DeviceAttribute,
+    DeviceAttributeHistory,
+    DeviceData,
+    DeviceDataHistory,
+    DevicePipe,
+    DbDatum,
+    DbDevInfo,
+    DbDevImportInfo,
+    DbDevExportInfo,
+    DbServerInfo,
+    GroupReply,
+    GroupAttrReply,
+    GroupCmdReply,
+    DevError,
+    EventData,
+    AttrConfEventData,
+    DataReadyEventData,
+    TimeVal,
+    DevFailed,
+    CmdArgType,
+)
 
 from .device_server import AttributeAlarm, EventProperties
 from .device_server import ChangeEventProp, PeriodicEventProp, ArchiveEventProp
@@ -40,22 +77,24 @@ import collections.abc
 
 
 def __inc_param(obj, name):
-    ret = not name.startswith('_')
-    ret &= name not in ('except_flags',)
+    ret = not name.startswith("_")
+    ret &= name not in ("except_flags",)
     ret &= not isinstance(getattr(obj, name), collections.abc.Callable)
     return ret
 
 
-def __single_param(obj, param_name, f=repr, fmt='%s = %s'):
+def __single_param(obj, param_name, f=repr, fmt="%s = %s"):
     param_value = getattr(obj, param_name)
-    if param_name == 'data_type':
+    if param_name == "data_type":
         param_value = CmdArgType.values.get(param_value, param_value)
     return fmt % (param_name, f(param_value))
 
 
-def __struct_params_s(obj, separator=', ', f=repr, fmt='%s = %s'):
+def __struct_params_s(obj, separator=", ", f=repr, fmt="%s = %s"):
     """method wrapper for printing all elements of a struct"""
-    s = separator.join([__single_param(obj, n, f, fmt) for n in dir(obj) if __inc_param(obj, n)])
+    s = separator.join(
+        [__single_param(obj, n, f, fmt) for n in dir(obj) if __inc_param(obj, n)]
+    )
     return s
 
 
@@ -66,19 +105,19 @@ def __struct_params_repr(obj):
 
 def __struct_params_str(obj, fmt, f=repr):
     """method wrapper for printing all elements of a struct."""
-    return __struct_params_s(obj, '\n', f=f, fmt=fmt)
+    return __struct_params_s(obj, "\n", f=f, fmt=fmt)
 
 
 def __repr__Struct(self):
     """repr method for struct"""
-    return f'{self.__class__.__name__}({__struct_params_repr(self)})'
+    return f"{self.__class__.__name__}({__struct_params_repr(self)})"
 
 
 def __str__Struct_Helper(self, f=repr):
     """str method for struct"""
     attrs = [n for n in dir(self) if __inc_param(self, n)]
-    fmt = attrs and '%%%ds = %%s' % max(map(len, attrs)) or "%s = %s"
-    return f'{self.__class__.__name__}[\n{__struct_params_str(self, fmt, f)}]\n'
+    fmt = attrs and "%%%ds = %%s" % max(map(len, attrs)) or "%s = %s"
+    return f"{self.__class__.__name__}[\n{__struct_params_str(self, fmt, f)}]\n"
 
 
 def __str__Struct(self):
@@ -94,11 +133,23 @@ def __registerSeqStr():
     _SeqStr = lambda self: (self and f"[{', '.join(map(repr, self))}]") or "[]"
     _SeqRepr = lambda self: (self and f"[{', '.join(map(repr, self))}]") or "[]"
 
-    seqs = (StdStringVector, StdLongVector, CommandInfoList,
-            AttributeInfoList, AttributeInfoListEx, PipeInfoList,
-            DeviceDataHistoryList,
-            GroupReplyList, GroupAttrReplyList, GroupCmdReplyList,
-            DbData, DbDevInfos, DbDevExportInfos, DbDevImportInfos, DbHistoryList)
+    seqs = (
+        StdStringVector,
+        StdLongVector,
+        CommandInfoList,
+        AttributeInfoList,
+        AttributeInfoListEx,
+        PipeInfoList,
+        DeviceDataHistoryList,
+        GroupReplyList,
+        GroupAttrReplyList,
+        GroupCmdReplyList,
+        DbData,
+        DbDevInfos,
+        DbDevExportInfos,
+        DbDevImportInfos,
+        DbHistoryList,
+    )
 
     for seq in seqs:
         seq.__str__ = _SeqStr
@@ -107,13 +158,13 @@ def __registerSeqStr():
 
 def __str__DevFailed(self):
     if isinstance(self.args, collections.abc.Sequence):
-        seq_str = '\n'.join(map(str, self.args))
-        return f'DevFailed[\n{seq_str}]'
-    return f'DevFailed[{self.args}]'
+        seq_str = "\n".join(map(str, self.args))
+        return f"DevFailed[\n{seq_str}]"
+    return f"DevFailed[{self.args}]"
 
 
 def __repr__DevFailed(self):
-    return f'DevFailed(args = {repr(self.args)})'
+    return f"DevFailed(args = {repr(self.args)})"
 
 
 def __str__DevError(self):
@@ -129,18 +180,48 @@ severity = {self.severity}]
 
 def __registerStructStr():
     """helper method to register str and repr methods for structures"""
-    structs = (LockerInfo, DevCommandInfo, AttributeDimension, CommandInfo,
-               DeviceInfo, DeviceAttributeConfig, AttributeInfo, AttributeAlarmInfo,
-               ChangeEventInfo, PeriodicEventInfo, ArchiveEventInfo,
-               AttributeEventInfo, AttributeInfoEx, PipeInfo,
-               DeviceAttribute, DeviceAttributeHistory, DeviceData, DeviceDataHistory,
-               DevicePipe, DbDatum, DbDevInfo, DbDevImportInfo, DbDevExportInfo,
-               DbServerInfo, GroupReply, GroupAttrReply, GroupCmdReply,
-               DevError, EventData, AttrConfEventData, DataReadyEventData,
-               AttributeConfig, AttributeConfig_2, AttributeConfig_3,
-               AttributeConfig_5,
-               ChangeEventProp, PeriodicEventProp, ArchiveEventProp,
-               AttributeAlarm, EventProperties)
+    structs = (
+        LockerInfo,
+        DevCommandInfo,
+        AttributeDimension,
+        CommandInfo,
+        DeviceInfo,
+        DeviceAttributeConfig,
+        AttributeInfo,
+        AttributeAlarmInfo,
+        ChangeEventInfo,
+        PeriodicEventInfo,
+        ArchiveEventInfo,
+        AttributeEventInfo,
+        AttributeInfoEx,
+        PipeInfo,
+        DeviceAttribute,
+        DeviceAttributeHistory,
+        DeviceData,
+        DeviceDataHistory,
+        DevicePipe,
+        DbDatum,
+        DbDevInfo,
+        DbDevImportInfo,
+        DbDevExportInfo,
+        DbServerInfo,
+        GroupReply,
+        GroupAttrReply,
+        GroupCmdReply,
+        DevError,
+        EventData,
+        AttrConfEventData,
+        DataReadyEventData,
+        AttributeConfig,
+        AttributeConfig_2,
+        AttributeConfig_3,
+        AttributeConfig_5,
+        ChangeEventProp,
+        PeriodicEventProp,
+        ArchiveEventProp,
+        AttributeAlarm,
+        EventProperties,
+    )
 
     for struct in structs:
         struct.__str__ = __str__Struct
