@@ -19,9 +19,12 @@ import inspect
 import logging
 import functools
 import traceback
+import asyncio
+import warnings
+import threading
 
 from ._tango import AttrDataFormat, AttrWriteType, CmdArgType, PipeWriteType
-from ._tango import DevFailed, GreenMode, SerialModel
+from ._tango import DevFailed, GreenMode, SerialModel, ApiUtil
 
 from .attr_data import AttrData
 from .pipe_data import PipeData
@@ -38,6 +41,7 @@ from .utils import (
 )
 from .utils import is_devstate, is_devstate_seq, scalar_to_array_type, TO_TANGO_TYPE
 from .green import get_green_mode, get_executor
+from .asyncio_executor import AsyncioExecutor
 from .pyutil import Util
 
 __all__ = (
@@ -58,6 +62,50 @@ API_VERSION = 2
 
 # Helpers
 
+_coverage_run_active = False
+
+try:
+    import coverage
+
+    if coverage.Coverage.current():
+        if ApiUtil.get_env_var("PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING"):
+            warnings.warn(
+                "Coverage run detected, but PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING "
+                "environment variable is set. Reported coverage may be inaccurate."
+            )
+        else:
+            if getattr(threading, "_trace_hook", None):
+                _coverage_run_active = True
+                warnings.warn(
+                    "Coverage run detected: tango.server.Device methods "
+                    "will be patched for tracing."
+                )
+            else:
+                warnings.warn(
+                    "Coverage run detected, but unable to get threading._trace_hook. "
+                    "Reported coverage may be inaccurate."
+                )
+
+except Exception:
+    pass
+
+
+def _force_threading_trace_hook(fn):
+    @functools.wraps(fn)
+    def trace_wrapper(*args, **kwargs):
+        original_tracer = sys.gettrace()
+
+        threading_trace_hook = getattr(threading, "_trace_hook", None)
+        if threading_trace_hook:
+            sys.settrace(threading_trace_hook)
+        try:
+            ret = fn(*args, **kwargs)
+        finally:
+            sys.settrace(original_tracer)
+        return ret
+
+    return trace_wrapper
+
 
 def _get_tango_type_format(dtype=None, dformat=None, caller=None):
     if dformat is None:
@@ -103,6 +151,9 @@ def __get_wrapped_read_method(attribute, read_method):
     if already_wrapped:
         return read_method
 
+    if _coverage_run_active:
+        read_method = _force_threading_trace_hook(read_method)
+
     if attribute.read_green_mode:
 
         @functools.wraps(read_method)
@@ -156,6 +207,9 @@ def __get_wrapped_write_method(attribute, write_method):
     if already_wrapped:
         return write_method
 
+    if _coverage_run_active:
+        write_method = _force_threading_trace_hook(write_method)
+
     if attribute.write_green_mode:
 
         @functools.wraps(write_method)
@@ -209,6 +263,9 @@ def __get_wrapped_isallowed_method(attribute, isallowed_method):
     if already_wrapped:
         return isallowed_method
 
+    if _coverage_run_active:
+        isallowed_method = _force_threading_trace_hook(isallowed_method)
+
     if attribute.isallowed_green_mode:
 
         @functools.wraps(isallowed_method)
@@ -274,6 +331,9 @@ def __get_wrapped_pipe_read_method(pipe, read_method):
     if already_wrapped:
         return read_method
 
+    if _coverage_run_active:
+        read_method = _force_threading_trace_hook(read_method)
+
     if pipe.read_green_mode:
 
         @functools.wraps(read_method)
@@ -325,6 +385,9 @@ def __get_wrapped_pipe_write_method(pipe, write_method):
     if already_wrapped:
         return write_method
 
+    if _coverage_run_active:
+        write_method = _force_threading_trace_hook(write_method)
+
     if pipe.write_green_mode:
 
         @functools.wraps(write_method)
@@ -378,6 +441,9 @@ def __get_wrapped_pipe_isallowed_method(pipe, isallowed_method):
     if already_wrapped:
         return isallowed_method
 
+    if _coverage_run_active:
+        isallowed_method = _force_threading_trace_hook(isallowed_method)
+
     if pipe.isallowed_green_mode:
 
         @functools.wraps(isallowed_method)
@@ -449,6 +515,9 @@ def __patch_is_command_allowed_method(tango_device_klass, is_allowed_method, cmd
     if already_wrapped:
         return is_allowed_method.__wrapped_method_name__
 
+    if _coverage_run_active:
+        is_allowed_method = _force_threading_trace_hook(is_allowed_method)
+
     method_name = getattr(is_allowed_method, "__name__", f"is_{cmd_name}_allowed")
     method_name = f"__wrapped_{method_name}__"
 
@@ -466,6 +535,8 @@ def __patch_standard_device_methods(klass):
     init_device_orig = klass.init_device
     already_wrapped = hasattr(init_device_orig, "__access_wrapped__")
     if not already_wrapped:
+        if _coverage_run_active:
+            init_device_orig = _force_threading_trace_hook(init_device_orig)
 
         @functools.wraps(init_device_orig)
         def init_device(self):
@@ -477,6 +548,8 @@ def __patch_standard_device_methods(klass):
     delete_device_orig = klass.delete_device
     already_wrapped = hasattr(delete_device_orig, "__access_wrapped__")
     if not already_wrapped:
+        if _coverage_run_active:
+            delete_device_orig = _force_threading_trace_hook(delete_device_orig)
 
         @functools.wraps(delete_device_orig)
         def delete_device(self):
@@ -488,10 +561,18 @@ def __patch_standard_device_methods(klass):
     dev_state_orig = klass.dev_state
     already_wrapped = hasattr(dev_state_orig, "__access_wrapped__")
     if not already_wrapped:
+        dev_state_async = klass._BaseDevice__asyncio_dev_state
+        is_base_klass_state = dev_state_orig == BaseDevice.dev_state
+        if _coverage_run_active:
+            dev_state_orig = _force_threading_trace_hook(dev_state_orig)
+            dev_state_async = _force_threading_trace_hook(dev_state_async)
 
         @functools.wraps(dev_state_orig)
         def dev_state(self):
-            return get_worker().execute(dev_state_orig, self)
+            if isinstance(get_worker(), AsyncioExecutor) and is_base_klass_state:
+                return get_worker().execute(dev_state_async, self)
+            else:
+                return get_worker().execute(dev_state_orig, self)
 
         dev_state.__access_wrapped__ = True
         setattr(klass, "dev_state", dev_state)
@@ -499,6 +580,8 @@ def __patch_standard_device_methods(klass):
     dev_status_orig = klass.dev_status
     already_wrapped = hasattr(dev_status_orig, "__access_wrapped__")
     if not already_wrapped:
+        if _coverage_run_active:
+            dev_status_orig = _force_threading_trace_hook(dev_status_orig)
 
         @functools.wraps(dev_status_orig)
         def dev_status(self):
@@ -510,6 +593,10 @@ def __patch_standard_device_methods(klass):
     read_attr_hardware_orig = klass.read_attr_hardware
     already_wrapped = hasattr(read_attr_hardware_orig, "__access_wrapped__")
     if not already_wrapped:
+        if _coverage_run_active:
+            read_attr_hardware_orig = _force_threading_trace_hook(
+                read_attr_hardware_orig
+            )
 
         @functools.wraps(read_attr_hardware_orig)
         def read_attr_hardware(self, attr_list):
@@ -521,6 +608,10 @@ def __patch_standard_device_methods(klass):
     always_executed_hook_orig = klass.always_executed_hook
     already_wrapped = hasattr(always_executed_hook_orig, "__access_wrapped__")
     if not already_wrapped:
+        if _coverage_run_active:
+            always_executed_hook_orig = _force_threading_trace_hook(
+                always_executed_hook_orig
+            )
 
         @functools.wraps(always_executed_hook_orig)
         def always_executed_hook(self):
@@ -529,12 +620,27 @@ def __patch_standard_device_methods(klass):
         always_executed_hook.__access_wrapped__ = True
         setattr(klass, "always_executed_hook", always_executed_hook)
 
+    server_init_hook_orig = klass.server_init_hook
+    already_wrapped = hasattr(server_init_hook_orig, "__access_wrapped__")
+    if not already_wrapped:
+
+        @functools.wraps(server_init_hook_orig)
+        def server_init_hook(self):
+            return get_worker().execute(server_init_hook_orig, self)
+
+        server_init_hook.__access_wrapped__ = True
+        setattr(klass, "server_init_hook", server_init_hook)
+
 
 class _DeviceClass(DeviceClass):
     def __init__(self, name):
         DeviceClass.__init__(self, name)
         self.set_type(name)
 
+        if _coverage_run_active:
+            orig_dyn_attr = getattr(self, "dyn_attr")
+            setattr(self, "dyn_attr", _force_threading_trace_hook(orig_dyn_attr))
+
     def dyn_attr(self, dev_list):
         """Invoked to create dynamic attributes for the given devices.
         Default implementation calls
@@ -731,6 +837,16 @@ class BaseDevice(LatestDeviceImpl):
     def read_attr_hardware(self, attr_list):
         return LatestDeviceImpl.read_attr_hardware(self, attr_list)
 
+    async def __asyncio_dev_state(self):
+        if sys.version_info >= (3, 9):
+            return await asyncio.to_thread(LatestDeviceImpl.dev_state, self)
+        else:
+            warnings.warn(
+                "DevState.ALARM cannot be correctly reported with GreenMode.Asyncio prior to Python 3.9"
+            )
+            # See https://gitlab.com/tango-controls/pytango/-/merge_requests/564 for details
+            return LatestDeviceImpl.dev_state(self)
+
     def dev_state(self):
         return LatestDeviceImpl.dev_state(self)
 
@@ -775,6 +891,14 @@ class BaseDevice(LatestDeviceImpl):
         """
         pass
 
+    def server_init_hook(self):
+        """
+        Tango server_init_hook.  Called once the device server admin device
+        (DServer) is exported.
+        Default implementation does nothing.
+        """
+        pass
+
     def initialize_dynamic_attributes(self):
         """
         Method executed at initializion phase to create dynamic
@@ -1383,6 +1507,9 @@ def command(
         def cmd(self, *args, **kwargs):
             return get_worker().execute(f, self, *args, **kwargs)
 
+    if _coverage_run_active:
+        cmd = _force_threading_trace_hook(cmd)
+
     cmd.__tango_command__ = name, [din, dout, config_dict]
 
     # try to create a minimalistic __doc__
