@@ -26,7 +26,7 @@ from argparse import ArgumentParser, ArgumentTypeError
 # Local imports
 from .server import run
 from .utils import is_non_str_seq
-from . import DeviceProxy, Database, Util
+from . import Database, DeviceProxy, DevFailed, Util
 
 __all__ = (
     "MultiDeviceTestContext",
@@ -37,14 +37,8 @@ __all__ = (
 
 # Helpers
 
-_WINDOWS = "nt" in os.name
-if not _WINDOWS:
-    _DEFAULT_THREAD_TIMEOUT = 3.0
-    _DEFAULT_PROCESS_TIMEOUT = 5.0
-else:
-    _DEFAULT_THREAD_TIMEOUT = 5.0
-    _DEFAULT_PROCESS_TIMEOUT = 7.0
-
+_DEFAULT_THREAD_TIMEOUT = 5.0
+_DEFAULT_PROCESS_TIMEOUT = 7.0
 
 IOR = collections.namedtuple(
     "IOR",
@@ -340,6 +334,8 @@ class MultiDeviceTestContext:
       True if the device server should be launched in a new process, otherwise
       use a new thread.  Note:  if the context will be used mutiple times, it
       may seg fault if the thread mode is chosen.
+      See the :ref:`issues <testing_approaches_issues>` and
+      :ref:`process kwarg <testing_approaches_process_kwarg>` discussion in the docs.
       Optional.  Default is thread.
     :type process:
       :py:obj:`bool`
@@ -499,12 +495,14 @@ class MultiDeviceTestContext:
         # Write properties
         for info in device_prop_info:
             device_name = info["name"]
-            properties = info.get("properties", {})
+            properties = dict(info.get("properties", {}))
             # Patch the property dict to avoid a PyTango bug
-            patched = {
-                key: value if value != "" else " " for key, value in properties.items()
-            }
-            db.put_device_property(device_name, patched)
+            for key, value in properties.items():
+                if is_non_str_seq(value):
+                    properties[key] = [v if v != "" else " " for v in value]
+                else:
+                    properties[key] = value if value != "" else " "
+            db.put_device_property(device_name, properties)
 
             memorized = info.get("memorized", {})
             munged = {
@@ -512,7 +510,18 @@ class MultiDeviceTestContext:
                 for (attribute_name, memorized_value) in memorized.items()
             }
             db.put_device_attribute_property(device_name, munged)
-        return db
+        try:
+            validated_db = Database(self.db)
+        except DevFailed:
+            with open(self.db, "r") as f:
+                content = f.read()
+            raise RuntimeError(
+                f"Invalid FileDatabase file was created.\n"
+                f"Check device properties (empty list or str?): "
+                f"{device_prop_info}.\n"
+                f"Problematic file has content:\n{content}"
+            )
+        return validated_db
 
     def delete_db(self):
         """delete temporary database file only if it was created by this class"""
