@@ -31,11 +31,19 @@ __all__ = (
     "state",
     "command_typed_values",
     "attribute_typed_values",
+    "dev_encoded_values",
     "server_green_mode",
     "attr_data_format",
     "get_server_port_via_pid",
 )
 
+UTF8_STRING = (
+    r"""ăѣ𝔠ծềſģȟᎥ𝒋ǩľḿꞑȯ𝘱𝑞𝗋𝘴ȶ𝞄𝜈ψ𝒙𝘆𝚣1234567890!@#$%^&*()-_=+[{]};:'",<.>/?~𝘈Ḇ𝖢𝕯٤ḞԍНǏ𝙅ƘԸⲘ𝙉০Ρ𝗤Ɍ𝓢ȚЦ𝒱Ѡ𝓧ƳȤ"""
+    r"""ả𝘢ѧᖯć𝗱ễ𝑓𝙜Ⴙ𝞲𝑗𝒌ļṃŉо𝞎𝒒ᵲꜱ𝙩ừ𝗏ŵ𝒙𝒚ź1234567890!@#$%^&*()-_=+[{]};:'",<.>/?~АḂⲤ𝗗𝖤𝗙ꞠꓧȊ𝐉𝜥ꓡ𝑀𝑵Ǭ𝙿𝑄Ŗ𝑆𝒯𝖴𝘝𝘞ꓫŸ𝜡"""
+    r"""𝜶ƀ𝖼ḋếᵮℊ𝙝Ꭵ𝕛кιṃդⱺ𝓅𝘲𝕣𝖘ŧ𝑢ṽẉ𝘅ყž1234567890!@#$%^&*()-_=+[{]};:'",<.>/?~Ѧ𝙱ƇᗞΣℱԍҤ١𝔍К𝓛𝓜ƝȎ𝚸𝑄Ṛ𝓢ṮṺƲᏔꓫ𝚈𝚭"""
+    r"""Ꮟçძ𝑒𝖿𝗀ḧ𝗂𝐣ҝɭḿ𝕟𝐨𝝔𝕢ṛ𝓼тú𝔳ẃ⤬𝝲𝗓1234567890!@#$%^&*()-_=+[{]};:'",<.>/?~𝖠Β𝒞𝘋𝙴𝓕ĢȞỈ𝕵ꓗʟ𝙼ℕ০𝚸𝗤ՀꓢṰǓⅤ𝔚Ⲭ𝑌𝙕𝘢𝕤"""
+)
+
 # char \x00 cannot be sent in a DevString. All other 1-255 chars can
 ints = tuple(range(1, 256))
 bytes_devstring = bytes(ints)
@@ -173,6 +181,16 @@ EXTRACT_AS = [
 
 BASE_TYPES = [float, int, str, bool]
 
+# we also test a large dataset to force memory allocation from heap,
+# to insure immediate segfault if we try to access data after dereferencing
+LARGE_DATA_SIZE = 1 * 1024**2  # 1 Mb seems to be enough
+
+DEV_ENCODED_DATA = {
+    "str": UTF8_STRING,
+    "bytes": UTF8_STRING.encode(),
+    "bytearray": bytearray(UTF8_STRING.encode()),
+}
+
 # these sets to test Device Server input arguments
 
 OS_SYSTEMS = ["linux", "win"]
@@ -349,6 +367,13 @@ if pytest:
         expected = lambda v: create_result(dtype, v)
         return dtype, values, expected
 
+    @pytest.fixture(
+        params=list(DEV_ENCODED_DATA.items()),
+        ids=list(DEV_ENCODED_DATA.keys()),
+    )
+    def dev_encoded_values(request):
+        return request.param
+
     @pytest.fixture(
         params=EXTRACT_AS, ids=[f"extract_as.{req_type}" for req_type, _ in EXTRACT_AS]
     )
