@@ -1,6 +1,11 @@
 """Load tango-specific pytest fixtures."""
 
-from tango.test_utils import state, command_typed_values, attribute_typed_values
+from tango.test_utils import (
+    state,
+    command_typed_values,
+    attribute_typed_values,
+    dev_encoded_values,
+)
 from tango.test_utils import server_green_mode, attr_data_format
 from tango.test_utils import extract_as, base_type
 import pytest
@@ -13,6 +18,7 @@ __all__ = (
     "state",
     "command_typed_values",
     "attribute_typed_values",
+    "dev_encoded_values",
     "server_green_mode",
     "attr_data_format",
     "extract_as",
