@@ -8,7 +8,12 @@ import pytest
 from io import StringIO
 
 from tango import (
-    EventType, GreenMode, DeviceProxy, AttrQuality, EnsureOmniThread, is_omni_thread,
+    EventType,
+    GreenMode,
+    DeviceProxy,
+    AttrQuality,
+    EnsureOmniThread,
+    is_omni_thread,
 )
 from tango.server import Device
 from tango.server import command, attribute
@@ -28,24 +33,25 @@ device_proxy_map = {
     GreenMode.Synchronous: DeviceProxy,
     GreenMode.Futures: futures_DeviceProxy,
     GreenMode.Asyncio: partial(asyncio_DeviceProxy, wait=True),
-    GreenMode.Gevent: gevent_DeviceProxy}
+    GreenMode.Gevent: gevent_DeviceProxy,
+}
 
 
 # Test device
 
-class EventDevice(Device):
 
+class EventDevice(Device):
     def init_device(self):
         self.set_change_event("attr", True, False)
-        self.set_data_ready_event('attr', True)
+        self.set_data_ready_event("attr", True)
 
     @attribute
     def attr(self):
-        return 0.
+        return 0.0
 
     @command
     def send_change_event(self):
-        self.push_change_event("attr", 1.)
+        self.push_change_event("attr", 1.0)
 
     @command
     def send_data_ready_event(self):
@@ -53,14 +59,11 @@ class EventDevice(Device):
 
     @command
     def send_change_event_with_timestamp(self):
-        self.push_change_event("attr", 2., 3., AttrQuality.ATTR_WARNING)
+        self.push_change_event("attr", 2.0, 3.0, AttrQuality.ATTR_WARNING)
 
     @command(dtype_in=str)
     def add_dyn_attr(self, name):
-        attr = attribute(
-            name=name,
-            dtype='float',
-            fget=self.read)
+        attr = attribute(name=name, dtype="float", fget=self.read)
         self.add_attribute(attr)
 
     @command(dtype_in=str)
@@ -73,11 +76,16 @@ class EventDevice(Device):
 
 # Device fixture
 
-@pytest.fixture(params=[GreenMode.Synchronous,
-                        GreenMode.Futures,
-                        GreenMode.Asyncio,
-                        GreenMode.Gevent],
-                scope="module")
+
+@pytest.fixture(
+    params=[
+        GreenMode.Synchronous,
+        GreenMode.Futures,
+        GreenMode.Asyncio,
+        GreenMode.Gevent,
+    ],
+    scope="module",
+)
 def event_device(request):
     green_mode = request.param
     context = DeviceTestContext(EventDevice, host="127.0.0.1", process=True)
@@ -87,6 +95,7 @@ def event_device(request):
 
 # Tests
 
+
 def test_subscribe_change_event(event_device):
     results_change_event = []
 
@@ -95,7 +104,8 @@ def test_subscribe_change_event(event_device):
 
     # Subscribe to change event
     eid_change = event_device.subscribe_event(
-        "attr", EventType.CHANGE_EVENT, callback_change, wait=True)
+        "attr", EventType.CHANGE_EVENT, callback_change, wait=True
+    )
     assert eid_change == 1
 
     # Trigger an event
@@ -106,11 +116,13 @@ def test_subscribe_change_event(event_device):
         if len(results_change_event) > 1:
             break
         time.sleep(DELAY_PER_RETRY)
-    if retry_count+1 >= MAX_RETRIES:
+    if retry_count + 1 >= MAX_RETRIES:
         timeout_seconds = retry_count * DELAY_PER_RETRY
-        pytest.fail(f'Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment')
+        pytest.fail(
+            f"Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment"
+        )
     # Test the event values
-    assert results_change_event == [0., 1.]
+    assert results_change_event == [0.0, 1.0]
     # Unsubscribe
     event_device.unsubscribe_event(eid_change)
 
@@ -123,7 +135,8 @@ def test_subscribe_data_ready_event(event_device):
 
     # Subscribe to data ready event
     eid_data_ready = event_device.subscribe_event(
-        "attr", EventType.DATA_READY_EVENT, callback_data_ready, wait=True)
+        "attr", EventType.DATA_READY_EVENT, callback_data_ready, wait=True
+    )
     assert eid_data_ready == 1
     # Trigger an event
     event_device.command_inout("send_data_ready_event", wait=True)
@@ -133,9 +146,11 @@ def test_subscribe_data_ready_event(event_device):
         if len(results_data_ready_event):
             break
         time.sleep(DELAY_PER_RETRY)
-    if retry_count+1 >= MAX_RETRIES:
+    if retry_count + 1 >= MAX_RETRIES:
         timeout_seconds = retry_count * DELAY_PER_RETRY
-        pytest.fail(f'Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment')
+        pytest.fail(
+            f"Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment"
+        )
     # Test the event values
     assert results_data_ready_event == [2]
     # Unsubscribe
@@ -150,51 +165,76 @@ def test_subscribe_interface_event(event_device):
 
     # Subscribe
     eid = event_device.subscribe_event(
-        "attr", EventType.INTERFACE_CHANGE_EVENT, callback, wait=True)
+        "attr", EventType.INTERFACE_CHANGE_EVENT, callback, wait=True
+    )
     assert eid == 1
     # Trigger an event
-    event_device.command_inout("add_dyn_attr", 'bla', wait=True)
-    event_device.read_attribute('bla', wait=True) == 1.23
+    event_device.command_inout("add_dyn_attr", "bla", wait=True)
+    event_device.read_attribute("bla", wait=True) == 1.23
     # Wait for tango event
     for retry_count in range(MAX_RETRIES):
         event_device.read_attribute("state", wait=True)
         if len(results) > 1:
             break
         time.sleep(DELAY_PER_RETRY)
-    if retry_count+1 >= MAX_RETRIES:
+    if retry_count + 1 >= MAX_RETRIES:
         timeout_seconds = retry_count * DELAY_PER_RETRY
-        pytest.fail(f'Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment')
-    event_device.command_inout("delete_dyn_attr", 'bla', wait=True)
+        pytest.fail(
+            f"Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment"
+        )
+    event_device.command_inout("delete_dyn_attr", "bla", wait=True)
     # Wait for tango event
     for retry_count in range(MAX_RETRIES):
         event_device.read_attribute("state", wait=True)
         if len(results) > 2:
             break
         time.sleep(DELAY_PER_RETRY)
-    if retry_count+1 >= MAX_RETRIES:
+    if retry_count + 1 >= MAX_RETRIES:
         timeout_seconds = retry_count * DELAY_PER_RETRY
-        pytest.fail(f'Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment')
+        pytest.fail(
+            f"Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment"
+        )
     # Test the first event value
-    assert {cmd.cmd_name for cmd in results[0].cmd_list} == \
-        {'Init', 'State', 'Status',
-         'add_dyn_attr', 'delete_dyn_attr',
-         'send_change_event', 'send_data_ready_event', 'send_change_event_with_timestamp'}
-    assert {att.name for att in results[0].att_list} == \
-        {'attr', 'State', 'Status'}
+    assert {cmd.cmd_name for cmd in results[0].cmd_list} == {
+        "Init",
+        "State",
+        "Status",
+        "add_dyn_attr",
+        "delete_dyn_attr",
+        "send_change_event",
+        "send_data_ready_event",
+        "send_change_event_with_timestamp",
+    }
+    assert {att.name for att in results[0].att_list} == {"attr", "State", "Status"}
     # Test the second event value
-    assert {cmd.cmd_name for cmd in results[1].cmd_list} == \
-        {'Init', 'State', 'Status',
-         'add_dyn_attr', 'delete_dyn_attr',
-         'send_change_event', 'send_data_ready_event', 'send_change_event_with_timestamp'}
-    assert {att.name for att in results[1].att_list} == \
-        {'attr', 'State', 'Status', 'bla'}
+    assert {cmd.cmd_name for cmd in results[1].cmd_list} == {
+        "Init",
+        "State",
+        "Status",
+        "add_dyn_attr",
+        "delete_dyn_attr",
+        "send_change_event",
+        "send_data_ready_event",
+        "send_change_event_with_timestamp",
+    }
+    assert {att.name for att in results[1].att_list} == {
+        "attr",
+        "State",
+        "Status",
+        "bla",
+    }
     # Test the third event value
-    assert {cmd.cmd_name for cmd in results[2].cmd_list} == \
-        {'Init', 'State', 'Status',
-         'add_dyn_attr', 'delete_dyn_attr',
-         'send_change_event', 'send_data_ready_event', 'send_change_event_with_timestamp'}
-    assert {att.name for att in results[2].att_list} == \
-        {'attr', 'State', 'Status'}
+    assert {cmd.cmd_name for cmd in results[2].cmd_list} == {
+        "Init",
+        "State",
+        "Status",
+        "add_dyn_attr",
+        "delete_dyn_attr",
+        "send_change_event",
+        "send_data_ready_event",
+        "send_change_event_with_timestamp",
+    }
+    assert {att.name for att in results[2].att_list} == {"attr", "State", "Status"}
     # Unsubscribe
     event_device.unsubscribe_event(eid)
 
@@ -203,8 +243,7 @@ def test_push_event_with_timestamp(event_device):
     string = StringIO()
     ec = EventCallback(fd=string)
     # Subscribe
-    eid = event_device.subscribe_event(
-        "attr", EventType.CHANGE_EVENT, ec, wait=True)
+    eid = event_device.subscribe_event("attr", EventType.CHANGE_EVENT, ec, wait=True)
     assert eid == 1
     # Trigger an event
     event_device.command_inout("send_change_event_with_timestamp", wait=True)
@@ -214,13 +253,15 @@ def test_push_event_with_timestamp(event_device):
         if len(ec.get_events()) > 1:
             break
         time.sleep(DELAY_PER_RETRY)
-    if retry_count+1 >= MAX_RETRIES:
+    if retry_count + 1 >= MAX_RETRIES:
         timeout_seconds = retry_count * DELAY_PER_RETRY
-        pytest.fail(f'Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment')
+        pytest.fail(
+            f"Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment"
+        )
     # Test the event values and timestamp
     results = [evt.attr_value.value for evt in ec.get_events()]
-    assert results == [0., 2.]
-    assert ec.get_events()[-1].attr_value.time.totime() == 3.
+    assert results == [0.0, 2.0]
+    assert ec.get_events()[-1].attr_value.time.totime() == 3.0
     # Check string
     line1 = "TEST/NODB/EVENTDEVICE ATTR#DBASE=NO CHANGE [ATTR_VALID] 0.0"
     line2 = "TEST/NODB/EVENTDEVICE ATTR#DBASE=NO CHANGE [ATTR_WARNING] 2.0"
@@ -243,12 +284,12 @@ def test_user_thread_is_not_omni_thread():
     thread_is_omni = dict(result=None)  # use a dict so thread can modify it
 
     def thread_func():
-        thread_is_omni['result'] = is_omni_thread()
+        thread_is_omni["result"] = is_omni_thread()
 
     thread = Thread(target=thread_func)
     thread.start()
     thread.join()
-    assert thread_is_omni['result'] is False
+    assert thread_is_omni["result"] is False
 
 
 def test_ensure_omni_thread_user_thread_is_omni_thread():
@@ -256,12 +297,12 @@ def test_ensure_omni_thread_user_thread_is_omni_thread():
 
     def thread_func():
         with EnsureOmniThread():
-            thread_is_omni['result'] = is_omni_thread()
+            thread_is_omni["result"] = is_omni_thread()
 
     thread = Thread(target=thread_func)
     thread.start()
     thread.join()
-    assert thread_is_omni['result'] is True
+    assert thread_is_omni["result"] is True
 
 
 def test_subscribe_change_event_from_user_thread(event_device):
@@ -273,7 +314,8 @@ def test_subscribe_change_event_from_user_thread(event_device):
     def thread_func():
         with EnsureOmniThread():
             eid = event_device.subscribe_event(
-                "attr", EventType.CHANGE_EVENT, callback, wait=True)
+                "attr", EventType.CHANGE_EVENT, callback, wait=True
+            )
             while running:
                 time.sleep(DELAY_PER_RETRY)
             event_device.unsubscribe_event(eid)
@@ -296,9 +338,10 @@ def test_subscribe_change_event_from_user_thread(event_device):
     # Stop the thread
     running = False
     thread.join()
-    if retry_count+1 >= MAX_RETRIES:
+    if retry_count + 1 >= MAX_RETRIES:
         timeout_seconds = retry_count * DELAY_PER_RETRY
-        pytest.fail(f'Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment')
+        pytest.fail(
+            f"Timeout, waiting for event, after {timeout_seconds}sec over {MAX_RETRIES} retries. Occasionally happens, probably due to CI test runtime environment"
+        )
     # Test the event values
-    assert results == [0., 1.]
-
+    assert results == [0.0, 1.0]
