@@ -1,9 +1,9 @@
 import os
-
 import pytest
-
 import tango
 
+import numpy as np
+
 from tango import AttrWriteType, GreenMode
 from tango.asyncio_executor import AsyncioExecutor
 from tango.device_server import get_worker
@@ -445,6 +445,15 @@ def test_multi_with_two_devices_with_properties(server_green_mode):
         assert proxy2.get_prop2() == 5555
 
 
+def test_multi_raises_on_invalid_file_database_properties():
+    class TestDevice(Device):
+        empty = device_property(dtype=(str,))
+
+    with pytest.raises(RuntimeError, match="FileDatabase"):
+        with DeviceTestContext(TestDevice, properties={"empty": []}):
+            pass
+
+
 @pytest.fixture(
     # Per test we have the input config tuple, and then the expected exception type
     params=[
@@ -575,3 +584,25 @@ def test_single_with_memorized_attribute_values(
 
     with DeviceTestContext(TestDevice, **kwargs) as proxy:
         assert proxy.attr == expected_value
+
+
+@pytest.mark.parametrize(
+    "property_type, property_value, expected_outcome",
+    [
+        (str, {"prop": ""}, " "),
+        ((str,), {"prop": ["", ""]}, (" ", " ")),
+        ((str,), {"prop": np.array(["", ""])}, (" ", " ")),
+    ],
+)
+def test_empty_string_property_bug(property_type, property_value, expected_outcome):
+    class TestDevice(Device):
+        prop = device_property(
+            dtype=property_type,
+        )
+
+        @attribute(dtype=property_type, max_dim_x=10)
+        def attr(self):
+            return self.prop
+
+    with DeviceTestContext(TestDevice, properties=property_value) as proxy:
+        assert proxy.attr == expected_outcome
